import { Subject } from 'rxjs';
import { PickupViewBase } from '@/studio-core';
import EAMMonitorPointService from '@/service/eammonitor-point/eammonitor-point-service';
import EAMMonitorPointAuthService from '@/authservice/eammonitor-point/eammonitor-point-auth-service';
import PickupViewEngine from '@engine/view/pickup-view-engine';
import EAMMonitorPointUIService from '@/uiservice/eammonitor-point/eammonitor-point-ui-service';

/**
 * 测点数据选择视图视图基类
 *
 * @export
 * @class EAMMonitorPointPickupViewBase
 * @extends {PickupViewBase}
 */
export class EAMMonitorPointPickupViewBase extends PickupViewBase {
    /**
     * 视图对应应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof EAMMonitorPointPickupViewBase
     */
    protected appDeName: string = 'eammonitorpoint';

    /**
     * 应用实体主键
     *
     * @protected
     * @type {string}
     * @memberof EAMMonitorPointPickupViewBase
     */
    protected appDeKey: string = 'eammonitorpointid';

    /**
     * 应用实体主信息
     *
     * @protected
     * @type {string}
     * @memberof EAMMonitorPointPickupViewBase
     */
    protected appDeMajor: string = 'eammonitorpointname';

    /**
     * 实体服务对象
     *
     * @type {EAMMonitorPointService}
     * @memberof EAMMonitorPointPickupViewBase
     */
    protected appEntityService: EAMMonitorPointService = new EAMMonitorPointService;

    /**
     * 实体权限服务对象
     *
     * @type EAMMonitorPointUIService
     * @memberof EAMMonitorPointPickupViewBase
     */
    public appUIService: EAMMonitorPointUIService = new EAMMonitorPointUIService(this.$store);


    /**
     * 计数器服务对象集合
     *
     * @protected
     * @type {Array<*>}
     * @memberof EAMMonitorPointPickupViewBase
     */    
    protected counterServiceArray: Array<any> = [];

    /**
     * 视图模型数据
     *
     * @protected
     * @type {*}
     * @memberof EAMMonitorPointPickupViewBase
     */
    protected model: any = {
        srfCaption: 'entities.eammonitorpoint.views.pickupview.caption',
        srfTitle: 'entities.eammonitorpoint.views.pickupview.title',
        srfSubTitle: 'entities.eammonitorpoint.views.pickupview.subtitle',
        dataInfo: ''
    }

    /**
     * 容器模型
     *
     * @protected
     * @type {*}
     * @memberof EAMMonitorPointPickupViewBase
     */
    protected containerModel: any = {
        view_pickupviewpanel: { name: 'pickupviewpanel', type: 'PICKUPVIEWPANEL' },
        view_okbtn: { name: 'okbtn', type: 'button', text: '确定', disabled: true },
        view_cancelbtn: { name: 'cancelbtn', type: 'button', text: '取消', disabled: false },
        view_leftbtn: { name: 'leftbtn', type: 'button', text: '左移', disabled: true },
        view_rightbtn: { name: 'rightbtn', type: 'button', text: '右移', disabled: true },
        view_allleftbtn: { name: 'allleftbtn', type: 'button', text: '全部左移', disabled: true },
        view_allrightbtn: { name: 'allrightbtn', type: 'button', text: '全部右移', disabled: true },
    };


	/**
     * 视图唯一标识
     *
     * @protected
     * @type {string}
     * @memberof ViewBase
     */
	protected viewtag: string = '3b351d19dc35d9e1f2bc5e4baf98e9b8';


    /**
     * 视图引擎
     *
     * @public
     * @type {Engine}
     * @memberof EAMMonitorPointPickupViewBase
     */
    public engine: PickupViewEngine = new PickupViewEngine();

    /**
     * 引擎初始化
     *
     * @public
     * @memberof EAMMonitorPointPickupViewBase
     */
    public engineInit(): void {
        this.engine.init({
            view: this,
            pickupviewpanel: this.$refs.pickupviewpanel,
            keyPSDEField: 'eammonitorpoint',
            majorPSDEField: 'eammonitorpointname',
            isLoadDefault: true,
        });
    }

    /**
     * pickupviewpanel 部件 selectionchange 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMMonitorPointPickupViewBase
     */
    public pickupviewpanel_selectionchange($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('pickupviewpanel', 'selectionchange', $event);
    }

    /**
     * pickupviewpanel 部件 activated 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMMonitorPointPickupViewBase
     */
    public pickupviewpanel_activated($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('pickupviewpanel', 'activated', $event);
    }

    /**
     * pickupviewpanel 部件 load 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMMonitorPointPickupViewBase
     */
    public pickupviewpanel_load($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('pickupviewpanel', 'load', $event);
    }


}